#
# spec file for package python-designateclient
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname python-designateclient
Name:           python-designateclient
Version:        2.9.0
Release:        lp151.3.3
Summary:        OpenStack DNS as a Service - Client
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://files.pythonhosted.org/packages/source/p/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-jsonschema >= 2.6.0
BuildRequires:  python-keystoneclient >= 3.8.0
BuildRequires:  python-mock >= 2.0.0
BuildRequires:  python-oslotest >= 3.2.0
BuildRequires:  python-pbr >= 2.0.0
BuildRequires:  python-python-subunit >= 1.0.0
BuildRequires:  python-requests-mock >= 1.1.0
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testrepository >= 0.0.18
Requires:       python-cliff >= 2.8.0
Requires:       python-debtcollector >= 1.2.0
Requires:       python-jsonschema >= 2.6.0
Requires:       python-keystoneauth1 >= 3.3.0
Requires:       python-keystoneclient >= 3.8.0
Requires:       python-osc-lib >= 1.8.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-requests >= 2.14.2
Requires:       python-six >= 1.10.0
Requires:       python-stevedore >= 1.20.0
BuildArch:      noarch

%description
OpenStack DNS as a Service - Client

%package doc
Summary:        Documentation for the OpenStack DNS as a Service - Client
Group:          Documentation/HTML
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme >= 1.18.1

%description doc
Documentation for the OpenStack DNS as a Service - Client.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%py2_build

# generate html docs
%{__python2} setup.py build_sphinx --builder=html,man
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%py2_install
# man pages
install -p -D -m 644 doc/build/man/*designateclient.1 %{buildroot}%{_mandir}/man1/designateclient.1

%check
%{__python2} setup.py testr

%files
%license LICENSE
%doc README.rst ChangeLog
%{python2_sitelib}/designateclient
%{python2_sitelib}/python_designateclient-%{version}-py2.?.egg-info
%{_bindir}/designate
%{_mandir}/man1/designateclient.1.*

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 2.9.0 (bsc#1078607)
  - Updated from global requirements
  - Partial Revert "Remove unneeded requirements file"
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.8.0
  - Improve recordset create UI
  - Split doc requirements into their own file
  - Update reno for stable/pike
  - Use jobs from designate repo
  - Remove setting of version/release from releasenotes
  - Make remote error handling more robust
  - Update the documentation link for doc migration
  - Avoid tox_install.sh for constraints support
  - Update and optimize documentation links
  - Remove unneeded requirements file
  - Updated from global requirements
  - Add tsig key support to python-designateclient
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.7.0
  - use setuptools to build the docs even for testing
  - rearrange the existing docs into the new standard layout
  - [Fix gate]Update test requirement
  - switch from oslosphinx to openstackdocstheme
  - import cli-reference material from openstack-manuals
  - Explicitly set 'builders' option
  - Set client module __version__
  - Simplify OSC doc structure
  - tox: Whitelist rm
  - doc: Remove cruft from conf.py
  - Update reno for stable/ocata
  - Update cli docs
  - Updated from global requirements
  - Use Sphinx 1.5 warning-is-error
* Tue Mar  7 2017 cloud-devel@suse.de
- update to version 2.6.0:
  - Removes unnecessary utf-8 encoding
  - Remove 'coding: utf-8' from  license statement
  - Add Constraints support
  - Fix broken link for modindex
  - Add attribute support to create zone cli
  - Show proper error on over quota commands
  - Replace 'assertFalse(a in b)' with 'assertNotIn(a, b)'
  - Add Python 3.5 classifier and venv
  - Updated from global requirements
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.4.0:
  - Add plug-in summary for osc doc
  - Update reno for stable/newton
  - Ensure X-Designate-Edit-Managed-Records header value is a string
  - Changed the author and author-email value
  - Updated from global requirements
  - Use tempest instead of Tempest-lib
  - Fix pep8 E501 line too long
  - record-create/update: Account for priority being 0
  - Show team and repo badges on README
  - Add oslo.config to test-requirements
  - Ensure X-Auth-All-Projects header value is a string
  - Enable release notes translation
  - Replace 'assertTrue(a in b)' with 'assertIn(a, b)'
  - Fix for bug 1627945
* Mon Sep 26 2016 tbechtold@suse.com
  update to version 2.3.0
  * Docs update for FloatingIP's ptr records
  * Resolve FloatingIP PTR records clis argument's description
  * Remove discover from test-requirements
  * Updated from global requirements
  * Fix clis related to FloatingIP's ptr records
* Mon Aug  1 2016 tbechtold@suse.com
- update to version 2.2.0:
  * Updated from global requirements
  * Use osc_lib instead of cliff
  * Add quota set / list / reset commands
  * Mark the v1 API Client as deprecated
  * Add global flags to cli
  * Use osc-lib instead of openstackclient
  * Revert "Add Global Flags for filtering results"
  * Add pool listing to python designate client
  * Add `openstack zone transfer accept list` cli to designateclient
  * Allow cli to query "v2/recordsets"
  * Add Global Flags for filtering results
  * Use the correct capitalization of OpenStack
  * Update the home-page with developer documentation
  * Add reno support for release notes
  * Switch to keystoneauth
  * Added CONTRIBUTING.rst file
  * Docs Update
  * Don't use the 'keystone' client (functional tests)
  * Update doc examples to use keystoneauth
  * Update designate cli page with more examples Closes-Bug: #1578207
  * Add python-openstackclient to test-requirements
  * Improve python-designateclient docs
  * Add support for service status
  * Fix a race condition in one of the zone import tests
  * Run the functional tests in a more verbose mode
  * Show responses on zone and recordset deletes
  * Implement zone import
  * Doc changes for installation webpage
  * Fix an issue causing a blacklist test to fail
  * Add filtering to recordsets CLI
  * Show "status" and "action" for recordsets
  * Move all V2 Controllers to inherit from the v2
  * Fixes 'openstack tld list' command's exception
  * Implement zone export
  * Improved TestRecordsetNegative
  * Add a service catalog override to the functional tests
  * Stop using non-existent method of Mock
  * Log stacktraces of MultipleExceptions in functionaltests
  * Python3: Add support for urlparse
  * Allow the OSC CLI Plugin to walk pages
  * Improvement in zone transfer request command description
  * Fixed grammar mistake in shell.rst
  * Update typos
  * Show output on transfer accept
  * Change to ShowOne to display output upon update
  * Put py34 first in the env order of tox
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Add a missing whitespace
  * Deprecated tox -downloadcache option removed
  * Indicate py34 support
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Pass environment variables of proxy to tox
  * Remove py26 support from designateclient
  * Improve logging in designateclient
  * Support OS_INTERFACE and set V2 API as default
  * Pass OS_ENDPOINT_TYPE from shell to client
  * Adds changes related to py3 compatibility
  * Clearing out .pyc file before a tox run
  * Fix support for --os-endpoint
  * Updates shell doc of v1 client
  * Fixes doc for v2 cli
  * Add functional tests for blacklists
  * Add functional tests for tlds
  * Adds different filter option for zone listing
  * Resolve TLD's by name
  * improve readme contents
  * Removes --name argument from zone set command
  * Fixes error over quota update
  * Fixes order of argument in assertEqual
  * Fixes typos in zone transfer request show command description
  * Add functional tests for recordsets
  * Flesh out zone-related test cases
  * Fixes exception message for zone creation command
  * Fixes target-project-id argument in zone transfer command
  * Removes name argument from openstack recordset set command
  * Fixes openstack zone blacklist set command
  * Added test cases for v2 client
  * Adds test cases for servers in designateclient
  * Adds test cases for domain in designate v1 client
  * Makes error msg more helpful
  * Add period in help message
  * Layout some functional tests for the V2 CLI
- update _service and switch to upstream spec file
* Sun Oct  4 2015 tbechtold@suse.com
- update to 1.5.0:
  * Updated from global requirements
  * Add formatting of output data
  * Added appropriate error message for designate cli
  * Meaningful Exception for over-quota on domains
  * Added test cases for reports in designateclient
  * Added diagnostics,sync and touch test cases for v1 designateclient
  * V2 CLI Support
  * Added quotas and servers test cases for designateclient
  * Added test cases for designate v1 client
  * Make is so exceptions have some message
  * Updated from global requirements
  * Update github's URL
  * Updated from global requirements
  * Implement socket timeout in v1
  * Don't wildcard resolve names
  * Updated from global requirements
  * Updated from global requirements
  * Improve help strings
* Fri Sep 25 2015 dmueller@suse.com
- add license
* Mon Sep 14 2015 tbechtold@suse.com
- update to 1.4.0:
  * Convert byte to str for py3 compatibilty
  * Updated from global requirements
  * Updated from global requirements
  * Add some missing Unit Tests to test_utils.py
  * Solve some py3 compatibilty issues
  * Fix py3 compatibilty issues
  * Updated from global requirements
  * Replacing print with print() to provide py 2/3 compatibility
  * Updated from global requirements
  * Updated from global requirements
  * Fix for ttl values
  * Log error message from EndpointNotFound exceptions
  * Removed peronal email address from example
  * Updated from global requirements
  * Fix backwards compat for edit_managed/all_tenants
  * Add .eggs to gitignore
  * Add backwards compat for edit_managed/all_tenants
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Update github link
  * Sync tox.ini and add py34
  * Use oslosphinx from PyPi
  * Drop incubating theme from docs
  * Move all_tenants and edit_managed attributes to designate Client
  * Log a more informative error upon EndpointNotFound
  * Updated from global requirements
  * V2 Bindings
  * Add --edit-managed flag to cli
  * Updated from global requirements
  * Allow relative names in record-create
  * Update README to work with release tools
  * Uncap library requirements for liberty
  * Allow to use domain names instead of ids
  * Updated from global requirements
  * Added extra previllege to list all domains from all tenants
  * Updated from global requirements
  * Updated from global requirements
  * Fix if checking on ttl for Create/Update commands
  * Updated from global requirements
  * Workflow documentation is now in infra-manual
  * Refactor KS session creation and support CA certs
  * Move some useful code outside v1
  * Make token + endpoints work correctly
  * Move session creation up to shell
  * Set defaults for endpoint_type and service_type
  * Updated from global requirements
  * Use keystone sessions for v1 client
  * Fixes homepage in metadata and internal docs
  * Updated from global requirements
  * Updated from global requirements
  * Fixes pypi tarball not delivering Apache 2.0 LICENSE file
  * Updated from global requirements
  * Updated from global requirements
- Adjust Requires according to requirements.txt
- Add python_requires to _service file
* Wed Sep 10 2014 dmueller@suse.com
- go back to version 1.1.0
* Sun Aug 31 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.17.ga900b41:
  * sync and touch Commands Extend the base.DeleteCommand
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.15.g5e69886:
  * Add support for SOA records
* Thu Aug 14 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.14.gedbc00a:
  * Updated from global requirements
* Mon Aug 11 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.13.g32e7a64:
  * Updated from global requirements
* Fri Aug  1 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.12.g322c455:
  * Add support for quotas for v1 cli / bindings
* Thu Jul 17 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.11.ge9adf2a:
  * Enable hacking check H104
  * Added oslosphinx theme, and enabled the incubating option
  * Support better logging (Fixes --debug option)
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.9.g975bc54:
  * Enabled hacking check H401
  * Support Keystone V3 authentication
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.6.gd4498bd:
  * Support better logging (Fixes --debug option
* Thu Jul  3 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.5.g9d4544f:
  * Update hacking package, fix/ignore new style errors
* Wed Jul  2 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.4.g5726896:
  * Updated from global requirements
* Sun Jun 29 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.3.g469afe1:
  * Update .gitreview for repository move
* Sat Jun  7 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.3.2.gd6bca95:
  * Use six.add_metaclass instead of __metaclass__
  * Add dummy tests
  1.0.3
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.2.3.g6025437:
  * designate record-list should display record data
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.2.2.ge6ff688:
  * Correct Python bindings create-record example
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.2.1.g11d4b42:
  * Standardize doc requirements
  1.0.2
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.1.2.gc6542d4:
  * Ensure that url stripping is done correctly
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.1.1.gb9e48a4:
  * Sync with global-requirements
  1.0.1
  * Support versionless catalog URLs
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version python-designateclient-1.0.0.14.ga8d2752:
  * Correctly support multiple regions
  * Update global requirements
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Thu Feb 13 2014 speilicke@suse.com
- Drop buildrequires of python-flake8, python-hacking, python-mox,
  python-pep8, python-pyflakes
* Tue Feb 11 2014 speilicke@suse.com
- Update to version python-designateclient-1.0.0.12.g3f43747:
  * Fix misspellings in python designateclient
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 1.0.0.11:
  + Sync with global requirements
  + Disable verbose logging by default
  + Remove dependencies on pep8, pyflakes and flake8
  + There are no mox tests, so remove dependency
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 1.0.0.4:
  + Fix and enable gating on H306
* Tue Dec  3 2013 speilicke@suse.com
- Run testsuite during build (%%check section) and obsolete the test
  package. An overall simplification of the test process
- Update to version 1.0.0.3:
  + No changes
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 0.0.5.6:
  + Added domain and record description editing
  + Remove outdated version value from setup.cfg
  + Keyring is not actually used
* Thu Oct 31 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.dev2:
  + Sync requirements with stable/havana requirements
* Mon Oct 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a1:
  + Ensure TTL is treated as an int in the CLI
* Sat Oct 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a9:
  + Update dependency versions
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a8:
  + Ensure Invalid JSON and errors during deletes are displayed correctly
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a7:
  + Add Python bindings docs
  + Correct two Record examples in the binding docs
* Wed Sep 25 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a5:
  + first drop of python-designateclient docs
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a4:
  + Ensure we only list sphinx as a dep once
  + Add a --insecure arg to ignore invalid SSL certs
  + Ensure beta versions are not downloaded from pypi
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a1:
  + Use Python 3.x compatible except construct.
* Tue Sep  3 2013 dmueller@suse.com
- fix requires
- remove unneeded requires
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 2013.1.a15:
  + Update to PBR 0.5.21+
  + Allow auth using a pre-fetched token
* Wed Jul 17 2013 speilicke@suse.com
- Drop LICENSE, run disabled source service
* Wed Jul 17 2013 speilicke@suse.com
- Initial version
